/**
 * HRM_C64 covert an image to HiRes bitmap mode
 *
 * The input file must be an not compressed TGA format
 * This manage only black and white color
 */

#include <iostream.h>
#include <fstream.h>
#include <stdlib.h>

#define DIMX 320
#define DIMY 200
#define NCOL 16

typedef unsigned short int byte;

// the image array
byte image[DIMX][DIMY];
byte best;                   // best color
ofstream *fo2;                // file for bank 2 output
ofstream *fo3;                // file for bank 3 output


/**
 * Read the TGA file image with the passed name
 *
 * @param name the name of the file
 */
void readImage(char *name) {
  int i,j;
  ifstream in(name, ios::in);
  in.seekg(0x18, ios::beg);

  for (int j=0; j<DIMY; j++) {
    for (int i=0; i<DIMX; i++) {
      //in >> image[i][j];
      image[i][j]=in.get();
    }
  }
}

/**
 * Codify a block 8x8 of the image
 *
 * @param x the x coord of the char block
 * @param y the y coord of the char block
 */
void codifyBlock(int x, int y) {
  int i,j;
  byte out;            // output byte
  int color[NCOL];
  byte colnum;         // color number actual processing
  
  cerr << "block x=" << x << " y=" << y << endl;

  //write info to output files
  fo2->put(0xf0);

  for (j=0; j<8; j++) {    //row scan
    out=0;
    for (i=0; i<8; i++) {  //col (pixels) scan
      colnum=image[x*8+i][y*8+j];
      out<<=1;
      if (colnum==0) {
        //out+=0x00;
      } else
         out+=0x01;
    }
    fo3->put(out);
  }
}

void codifyImage() {
  int x,y;
  
  for (y=0; y<DIMY/8; y++) {
    for (x=0; x<DIMX/8; x++) {
      codifyBlock(x,y);
    }
  }


/*  for (y=0; y<DIMY/8; y++) {
    for (x=35; x<DIMX/8; x++) {
        codifyBlock(x,y);
    }
    for (x=0; x<35; x++) {
      codifyBlock(x,y);
    }
  }*/
}

int main(int argc, char **argv) {
  if (argc<1) return 1;

  cout << "HRM_C64 0.1: convert a TGA not compressed 320*200 image in C64 raw data\n";

  readImage(argv[1]);
  fo2=new ofstream("b2.raw", ios::out);
  fo3=new ofstream("b3.raw", ios::out);

  codifyImage();


  delete fo2;
  delete fo3;

  return 0;
}

